==> image-data-domain-0.0.96-sources.jar: com/xforceplus/elephant/entity/ConfigSettings.java <==
package com.xforceplus.elephant.entity;

import java.time.LocalDateTime;
import java.io.Serializable;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

/**
 * <p>
 * 
 * </p>
 *
 * @author wangzheng
 * @since 2020-07-01
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
public class ConfigSettings implements Serializable {

  private static final long serialVersionUID=1L;

  private String isDefault;

  private String enable;

  private Long id;

  private Long tenantId;

  private LocalDateTime createTime;

  private LocalDateTime updateTime;

  private Long createUserId;

  private Long updateUserId;

  private String createUserName;

  private String updateUserName;

  private String deleteFlag;

  private Long tenant;

  private Long imageToAnnexSeconds;

  private String scanIsSupportAllTenant;

  private Long searchNoRealDay;

  private String ticketAutoSendVerify;

  private String isAllPushData;

  private String ticketIsSupportReuse;

  private String ticketIsCheckBlack;

  private String ticketIsCheckSensitive;

  private String ticketIsCheckLegalperson;

  private String billCodeIsNeedTrans;

  private String emptyUrl;

  private String isSupportPszs;

  private String debugModel;

  private String splitMoreImage;

  private String billTypeCodeNeedList;

  private String billCodeRegexSplit;

  private String tenantCode;

  private String extension1;

  private String extension2;

  private String extension3;

  private String salesListConfig;




        }

==> image-data-domain-0.0.124-sources.jar: com/xforceplus/elephant/entity/ConfigSettings.java <==
package com.xforceplus.elephant.entity;

import java.time.LocalDateTime;
import com.baomidou.mybatisplus.annotation.FieldFill;
import com.baomidou.mybatisplus.annotation.TableField;
import java.io.Serializable;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

/**
 * <p>
 * 
 * </p>
 *
 * @author wangzheng
 * @since 2020-07-31
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
public class ConfigSettings implements Serializable {

  private static final long serialVersionUID=1L;

  private String isDefault;

  private String enable;

  private Long id;

  @TableField(fill = FieldFill.INSERT)
  private Long tenantId;

  @TableField(fill = FieldFill.INSERT)
  private LocalDateTime createTime;

  @TableField(fill = FieldFill.INSERT_UPDATE)
  private LocalDateTime updateTime;

  @TableField(fill = FieldFill.INSERT)
  private Long createUserId;

  @TableField(fill = FieldFill.INSERT_UPDATE)
  private Long updateUserId;

  @TableField(fill = FieldFill.INSERT)
  private String createUserName;

  @TableField(fill = FieldFill.INSERT_UPDATE)
  private String updateUserName;

  @TableField(fill = FieldFill.INSERT)
  private String deleteFlag;

  private Long tenant;

  private Long imageToAnnexSeconds;

  private String scanIsSupportAllTenant;

  private Long searchNoRealDay;

  private String ticketAutoSendVerify;

  private String isAllPushData;

  private String ticketIsSupportReuse;

  private String ticketIsCheckBlack;

  private String ticketIsCheckSensitive;

  private String ticketIsCheckLegalperson;

  private String billCodeIsNeedTrans;

  private String emptyUrl;

  private String isSupportPszs;

  private String debugModel;

  private String splitMoreImage;

  private String billTypeCodeNeedList;

  private String billCodeRegexSplit;

  @TableField(fill = FieldFill.INSERT)
  private String tenantCode;

  private String extension1;

  private String extension2;

  private String extension3;

  private String salesListConfig;

  private String scanClientScanModel;




        }
